guix-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: 15/33: gnu: coreutils: Remove libcap dependency for the Hurd.


From: Jan Nieuwenhuizen
Subject: Re: 15/33: gnu: coreutils: Remove libcap dependency for the Hurd.
Date: Wed, 11 Mar 2020 16:01:09 +0100
User-agent: Gnus/5.13 (Gnus v5.13) Emacs/26.3 (gnu/linux)

Ludovic Courtès writes:

> address@hidden skribis:
>>               ;; Drop the dependency on libcap when cross-compiling since 
>> it's
>>               ;; not quite cross-compilable.
>> -             ,@(if (%current-target-system)
>> +             ;; Also, libcap is not available on the Hurd.
>> +             ,@(if (or (%current-target-system)
>> +                       (hurd-target?))
>
> Perhaps we’d also need something based on ‘supported-platforms’ here.
> (Not a blocker, though.)

Ah yes, I think that's the right way forward.  Changed it to

commit 7653827b8919ad85d025ba1a701ba38ab7d2e388
Author: Jan Nieuwenhuizen <address@hidden>
Date:   Sat Mar 7 03:53:38 2020 -0500

    gnu: coreutils: Remove libcap dependency for the Hurd.
    
    * gnu/packages/linux.scm (libcap)[supported-systems]: Remove the Hurd.
    * gnu/packages/base.scm (coreutils)[inputs]: Include libcap only for 
supported
    systems.  Fixes building on the Hurd.

diff --git a/gnu/packages/linux.scm b/gnu/packages/linux.scm
index e1959b905c..6bbe132476 100644
--- a/gnu/packages/linux.scm
+++ b/gnu/packages/linux.scm
@@ -2068,6 +2068,7 @@ configuration (iptunnel, ipmaddr).")
                                                    (assoc-ref %outputs "out"))
                                     "RAISE_SETFCAP=no")))
     (native-inputs `(("perl" ,perl)))
+    (supported-systems (delete "i586-gnu" %supported-systems))
     (home-page "https://sites.google.com/site/fullycapable/";)
     (synopsis "Library for working with POSIX capabilities")
     (description

I am planning a hard reset of wip-hurd when `hello' builds natively
again (and cross builds), hopefully later today.

janneke

diff --git a/gnu/packages/base.scm b/gnu/packages/base.scm
index f562a8fef7..03d9e4c0c1 100644
--- a/gnu/packages/base.scm
+++ b/gnu/packages/base.scm
@@ -303,11 +303,13 @@ used to apply commands with arbitrarily long arguments.")
    (inputs `(("acl"  ,acl)                        ; TODO: add SELinux
              ("gmp"  ,gmp)                        ;bignums in 'expr', yay!
 
-             ;; Drop the dependency on libcap when cross-compiling since it's
-             ;; not quite cross-compilable.
-             ,@(if (%current-target-system)
-                   '()
-                   `(("libcap" ,libcap)))))  ;capability support is 'ls', etc.
+             ;; Do not use libcap when cross-compiling since it's not quite
+             ;; cross-compilable; and use it only for supported systems.
+             ,@(if (and (not (%current-target-system))
+                        (not (member (%current-system)
+                                     (package-supported-systems libcap))))
+             `(("libcap" ,libcap))  ;capability support is 'ls', etc.
+             '())))
    (native-inputs
     ;; Perl is needed to run tests in native builds, and to run the bundled
     ;; copy of help2man.  However, don't pass it when cross-compiling since
-- 
Jan Nieuwenhuizen <address@hidden> | GNU LilyPond http://lilypond.org
Freelance IT http://JoyofSource.com | Avatar® http://AvatarAcademy.com



reply via email to

[Prev in Thread] Current Thread [Next in Thread]